===============
Django-Village
===============

Django-Village is an attempt at rendering a generique version of Django-VILLAGE. 

Documentation
-------------

It is my conviction that the work done in DSFR (`"Système de design de l’État français" <https://www.systeme-de-design.gouv.fr/>`_)  and as visible in the Django-VILLAGE Python Package (`documentation (in French) <https://numerique-gouv.github.io/django-village/>`_) is fantastic. The only problem is that the website design itself is the French Government, and not any lamba website. 

So, unless you want the French Foriegn Legion knocking at your door (actually, it wouldn't be them, but they are well known enough to illustrate my point), we need the grace to accept a very intentional work to bettering web-mastery, readability and accessibility by all. 

France, though its' DiNum, or, actually I won't get into it, just be aware that French coolness also goes to OpenSource communities, has made something called "(`sites-failes <https://github.com/numerique-gouv/sites-faciles>`_)" as a Wagtail plugin. I think it's great! That's why Village.

As the French Government uses django-village for sites-faciles, let's use django-village for "(`wagtail-facile <https://github.com/chris2fr/wagtail-village>`_)".

Requirements
------------
(from django-village)

Tested with Python 3.8 to 3.11 and Django 3.2 to 5.0. Per `vermin <https://github.com/netromdk/vermin>`_, it should work with Python >= 3.6, and it should work with old versions of Django too.

Note: Only supported versions of Django and Python are supported by this project. You can check the supported versions and their end of life on the following pages:

- `Python <https://devguide.python.org/versions/>`_
- `Django <https://www.djangoproject.com/download/#supported-versions>`_

Quick start
-----------
(from django-village)

See the `INSTALL.md <INSTALL.md>`_ file.
